@@ -1,3 +1,6 @@
+from rasa_model_report.helpers import utils
+
+
 class Controller:
     """
     Controller base class.
@@ -20,9 +23,9 @@ class Controller:
         """
         self.project_name: str = project_name
         self.project_version: str = project_version
-        self.rasa_path: str = rasa_path
-        self.actions_path = (kwargs.get("actions_path") or f"{self.rasa_path}/actions/").replace("//", "/")
-        self.output_path: str = output_path.replace("//", "/")
-        self.nlu_path: str = f"{self.rasa_path}/data".replace("//", "/")
-        self.results_path: str = f"{self.rasa_path}/results".replace("//", "/")
-        self.config_report_path: str = f"{self.rasa_path}/config.yml".replace("//", "/")
+        self.rasa_path: str = utils.remove_duplicate_slashs(rasa_path)
+        self.actions_path = utils.remove_duplicate_slashs(kwargs.get("actions_path") or f"{self.rasa_path}/actions/")
+        self.output_path: str = utils.remove_duplicate_slashs(output_path)
+        self.nlu_path: str = utils.remove_duplicate_slashs(f"{self.rasa_path}/data")
+        self.results_path: str = utils.remove_duplicate_slashs(f"{self.rasa_path}/results")
+        self.config_report_path: str = utils.remove_duplicate_slashs(f"{self.rasa_path}/config.yml")
